djmongo - A Django application for building APIs without code
=============================================================

django-djmongo is an "API in a Box".  It provides a web-based UI for 
MongoDB management and RESTful API management. 

If you do not have a Django project setup aslready use our sample project
with Djmongo already configured. https://github.com/videntity/djmsample.

djmsample uses on Python 3.6 and Django 3.0.3.

See the [Wiki](https://github.com/videntity/django-djmongo/wiki/Installation) page for installation and further documentation.
